<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>RecentFiles</name>
    <message>
        <source>Clear List</source>
        <translation type="obsolete">Liste löschen</translation>
    </message>
    <message>
        <location filename="../RecentFilesInit.js" line="+51"/>
        <source>&amp;Clear List</source>
        <translation>Liste &amp;löschen</translation>
    </message>
    <message>
        <source>Load/Save</source>
        <translation type="vanished">Laden/Speichern</translation>
    </message>
    <message>
        <location filename="../RecentFiles.js" line="+35"/>
        <source>Recent Files</source>
        <translation>Zuletzt geöffnete Dateien</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <source>Open/Save</source>
        <translation type="vanished">Laden/Speichern</translation>
    </message>
    <message>
        <location filename="../RecentFilesInit.js" line="+10"/>
        <source>Open &amp;Recent</source>
        <translation>&amp;Zuletzt geöffnete Dateien</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Recent files history size:</source>
        <translation>Anzahl zuletzt geöffnete Dateien:</translation>
    </message>
</context>
</TS>
